orion.primitives.tadgan.TadGAN
==============================

.. currentmodule:: orion.primitives.tadgan

.. autoclass:: TadGAN

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TadGAN.__init__
      ~TadGAN.fit
      ~TadGAN.predict
   
   

   
   
   